mathtools.NonreducedFraction
============================

.. abjad-lineage:: abjad.tools.mathtools.NonreducedFraction.NonreducedFraction.NonreducedFraction

.. autoclass:: abjad.tools.mathtools.NonreducedFraction.NonreducedFraction.NonreducedFraction
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.mathtools.NonreducedFraction.NonreducedFraction.NonreducedFraction.denominator
   :noindex:

.. autoattribute:: abjad.tools.mathtools.NonreducedFraction.NonreducedFraction.NonreducedFraction.imag
   :noindex:

.. autoattribute:: abjad.tools.mathtools.NonreducedFraction.NonreducedFraction.NonreducedFraction.numerator
   :noindex:

.. autoattribute:: abjad.tools.mathtools.NonreducedFraction.NonreducedFraction.NonreducedFraction.pair
   :noindex:

.. autoattribute:: abjad.tools.mathtools.NonreducedFraction.NonreducedFraction.NonreducedFraction.real
   :noindex:

.. autoattribute:: abjad.tools.mathtools.NonreducedFraction.NonreducedFraction.NonreducedFraction.storage_format
   :noindex:

Methods
-------

.. automethod:: abjad.tools.mathtools.NonreducedFraction.NonreducedFraction.NonreducedFraction.conjugate
   :noindex:

.. automethod:: abjad.tools.mathtools.NonreducedFraction.NonreducedFraction.NonreducedFraction.from_decimal
   :noindex:

.. automethod:: abjad.tools.mathtools.NonreducedFraction.NonreducedFraction.NonreducedFraction.from_float
   :noindex:

.. automethod:: abjad.tools.mathtools.NonreducedFraction.NonreducedFraction.NonreducedFraction.limit_denominator
   :noindex:

.. automethod:: abjad.tools.mathtools.NonreducedFraction.NonreducedFraction.NonreducedFraction.multiply_with_cross_cancelation
   :noindex:

.. automethod:: abjad.tools.mathtools.NonreducedFraction.NonreducedFraction.NonreducedFraction.multiply_with_numerator_preservation
   :noindex:

.. automethod:: abjad.tools.mathtools.NonreducedFraction.NonreducedFraction.NonreducedFraction.multiply_without_reducing
   :noindex:

.. automethod:: abjad.tools.mathtools.NonreducedFraction.NonreducedFraction.NonreducedFraction.reduce
   :noindex:

.. automethod:: abjad.tools.mathtools.NonreducedFraction.NonreducedFraction.NonreducedFraction.with_denominator
   :noindex:

.. automethod:: abjad.tools.mathtools.NonreducedFraction.NonreducedFraction.NonreducedFraction.with_multiple_of_denominator
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.mathtools.NonreducedFraction.NonreducedFraction.NonreducedFraction.__abs__
   :noindex:

.. automethod:: abjad.tools.mathtools.NonreducedFraction.NonreducedFraction.NonreducedFraction.__add__
   :noindex:

.. automethod:: abjad.tools.mathtools.NonreducedFraction.NonreducedFraction.NonreducedFraction.__complex__
   :noindex:

.. automethod:: abjad.tools.mathtools.NonreducedFraction.NonreducedFraction.NonreducedFraction.__div__
   :noindex:

.. automethod:: abjad.tools.mathtools.NonreducedFraction.NonreducedFraction.NonreducedFraction.__divmod__
   :noindex:

.. automethod:: abjad.tools.mathtools.NonreducedFraction.NonreducedFraction.NonreducedFraction.__eq__
   :noindex:

.. automethod:: abjad.tools.mathtools.NonreducedFraction.NonreducedFraction.NonreducedFraction.__float__
   :noindex:

.. automethod:: abjad.tools.mathtools.NonreducedFraction.NonreducedFraction.NonreducedFraction.__floordiv__
   :noindex:

.. automethod:: abjad.tools.mathtools.NonreducedFraction.NonreducedFraction.NonreducedFraction.__ge__
   :noindex:

.. automethod:: abjad.tools.mathtools.NonreducedFraction.NonreducedFraction.NonreducedFraction.__gt__
   :noindex:

.. automethod:: abjad.tools.mathtools.NonreducedFraction.NonreducedFraction.NonreducedFraction.__hash__
   :noindex:

.. automethod:: abjad.tools.mathtools.NonreducedFraction.NonreducedFraction.NonreducedFraction.__le__
   :noindex:

.. automethod:: abjad.tools.mathtools.NonreducedFraction.NonreducedFraction.NonreducedFraction.__lt__
   :noindex:

.. automethod:: abjad.tools.mathtools.NonreducedFraction.NonreducedFraction.NonreducedFraction.__mod__
   :noindex:

.. automethod:: abjad.tools.mathtools.NonreducedFraction.NonreducedFraction.NonreducedFraction.__mul__
   :noindex:

.. automethod:: abjad.tools.mathtools.NonreducedFraction.NonreducedFraction.NonreducedFraction.__ne__
   :noindex:

.. automethod:: abjad.tools.mathtools.NonreducedFraction.NonreducedFraction.NonreducedFraction.__neg__
   :noindex:

.. automethod:: abjad.tools.mathtools.NonreducedFraction.NonreducedFraction.NonreducedFraction.__nonzero__
   :noindex:

.. automethod:: abjad.tools.mathtools.NonreducedFraction.NonreducedFraction.NonreducedFraction.__pos__
   :noindex:

.. automethod:: abjad.tools.mathtools.NonreducedFraction.NonreducedFraction.NonreducedFraction.__pow__
   :noindex:

.. automethod:: abjad.tools.mathtools.NonreducedFraction.NonreducedFraction.NonreducedFraction.__radd__
   :noindex:

.. automethod:: abjad.tools.mathtools.NonreducedFraction.NonreducedFraction.NonreducedFraction.__rdiv__
   :noindex:

.. automethod:: abjad.tools.mathtools.NonreducedFraction.NonreducedFraction.NonreducedFraction.__rdivmod__
   :noindex:

.. automethod:: abjad.tools.mathtools.NonreducedFraction.NonreducedFraction.NonreducedFraction.__repr__
   :noindex:

.. automethod:: abjad.tools.mathtools.NonreducedFraction.NonreducedFraction.NonreducedFraction.__rfloordiv__
   :noindex:

.. automethod:: abjad.tools.mathtools.NonreducedFraction.NonreducedFraction.NonreducedFraction.__rmod__
   :noindex:

.. automethod:: abjad.tools.mathtools.NonreducedFraction.NonreducedFraction.NonreducedFraction.__rmul__
   :noindex:

.. automethod:: abjad.tools.mathtools.NonreducedFraction.NonreducedFraction.NonreducedFraction.__rpow__
   :noindex:

.. automethod:: abjad.tools.mathtools.NonreducedFraction.NonreducedFraction.NonreducedFraction.__rsub__
   :noindex:

.. automethod:: abjad.tools.mathtools.NonreducedFraction.NonreducedFraction.NonreducedFraction.__rtruediv__
   :noindex:

.. automethod:: abjad.tools.mathtools.NonreducedFraction.NonreducedFraction.NonreducedFraction.__str__
   :noindex:

.. automethod:: abjad.tools.mathtools.NonreducedFraction.NonreducedFraction.NonreducedFraction.__sub__
   :noindex:

.. automethod:: abjad.tools.mathtools.NonreducedFraction.NonreducedFraction.NonreducedFraction.__truediv__
   :noindex:

.. automethod:: abjad.tools.mathtools.NonreducedFraction.NonreducedFraction.NonreducedFraction.__trunc__
   :noindex:
